writeDataForImport: Prepare a Data Frame for Import Through the API
Description
Converts a dataframe into a character value in the format
of a CSV for import through the API.
Usage
writeDataForImport(data, csv_delimiter = ",")
Arguments
- data
data.frame to be imported to the API
- csv_delimiter
character(1) Delimiter used to separate fields in the generated CSV
string. Defaults to ",".